#
# spec file for package sddm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?is_backports}
%bcond_without sle_branding
%else
%bcond_with sle_branding
%endif

Name:           sddm
Version:        0.18.0
Release:        lp151.3.6.1
Summary:        QML-based display manager
License:        GPL-2.0+
Group:          System/GUI/KDE
Url:            https://github.com/sddm/sddm
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        X11-displaymanagers-%{name}
Source2:        00-general.conf
Source3:        10-theme.conf
Source4:        sddm-tmpfiles.conf
Source5:        10-theme-SLE.conf
# Patch0-100: PATCH-FIX-UPSTREAM
# Merged: https://github.com/sddm/sddm/pull/1062
Patch0:         0001-Session-reuse-Only-consider-online-sessions.patch
# No PR, committed directly
Patch1:         0001-Use-C-scoping-for-handling-buffer-deletion.patch
Patch2:         0001-Fix-X-not-having-access-control-on-startup.patch
Patch3:         0002-Don-t-disable-authentication-in-test-mode.patch
# Not merged yet: https://github.com/sddm/sddm/pull/997
Patch50:        0001-Remove-suffix-for-Wayland-session.patch
# Not merged yet: https://github.com/sddm/sddm/pull/1017
Patch51:        0006-Don-t-fill-UserModel-if-theme-does-not-require-it.patch
# Open issue: https://github.com/sddm/sddm/issues/1059
Patch52:        0001-Revert-Adds-sourcing-of-etc-profile-to-fish.patch
# Not merged yet: https://github.com/sddm/sddm/pull/1117
Patch53:        0001-Destroy-the-QLocalServer-in-Auth-on-shutdown.patch
# Patch100-?: PATCH-FIX-OPENSUSE
# Use openSUSE pam config
Patch100:       proper_pam.diff
Patch101:       0001-Write-the-daemon-s-PID-to-a-file-on-startup.patch
# Insert XAUTHLOCALHOSTNAME into users enviroment, so the session handles hostname changes with a single X instance/run
# related patches: libxcb/bug-262309_xcb-xauthlocalhostname.diff, xauth/xauth-tolerant-hostname-changes.diff, kdebase4-workspace/kdm-relaxed-auth.diff
Patch102:       sddm-relaxed-auth.patch
Patch103:       0001-Read-the-DISPLAYMANAGER_AUTOLOGIN-value-from-sysconf.patch
# sddm has some rudimentary support for plymouth handling, which only works with plymouth-quit.service
# (the servce is not enabled on openSUSE). For users of sddm.service, we need to issue plymouth quit command by hand in this case
Patch104:       sddm-service-handle-plymouth.patch
# Use tty7 by default in the systemd service unit
Patch105:       0001-Systemd-service-unit-Use-tty7-by-default.patch
Patch107:       0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
Patch108:       0001-Support-both-X11-XDisplay-Wayland-and-WaylandDisplay.patch
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules >= 1.4.0
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
# Autodetect UID_MIN and UID_MAX from /etc/login.defs
BuildRequires:  shadow
BuildRequires:  pkgconfig(Qt5Core) >= 5.6.0
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(xcb-xkb)
Requires(post): diffutils
Requires:       sddm-branding = %{version}
Requires:       xdm
Supplements:    plasma5-workspace
# Merged the -lang package back into the main package
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
%if 0%{?sle_version} < 150000 && !0%{?is_opensuse}
BuildRequires:  python-docutils
%else
BuildRequires:  python3-docutils
%endif

%description
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.

%package branding-openSUSE
Summary:        openSUSE branding for SDDM, a QML-based display manager
Group:          System/GUI/KDE
Requires:       sddm-theme-openSUSE
Requires:       %{name} = %{version}
Requires(post): %{name}
Requires(post): diffutils
Supplements:    packageand(%{name}:branding-openSUSE)
Conflicts:      otherproviders(sddm-branding)
Provides:       sddm-branding = %{version}

%description branding-openSUSE
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.
This package provides the openSUSE branding for SDDM.

%if %{with sle_branding}
%package branding-SLE
Summary:        SLE branding for SDDM, a QML-based display manager
Group:          System/GUI/KDE
Requires:       sddm-theme-SLE
Requires:       %{name} = %{version}
Requires(post): %{name}
Requires(post): diffutils
Supplements:    packageand(%{name}:branding-SLE)
Conflicts:      otherproviders(sddm-branding)
Provides:       sddm-branding = %{version}

%description branding-SLE
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.
This package provides the SLE branding for SDDM.
%endif

%package branding-upstream
Summary:        Upstream branding for SDDM, a QML-based display manager
Group:          System/GUI/KDE
Requires:       %{name} = %{version}
Requires(post): %{name}
Requires(post): diffutils
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(sddm-branding)
Provides:       sddm-branding = %{version}

%description branding-upstream
SDDM is a display manager for X11. It uses technologies like QtQuick,
which in turn gives the designer the ability to create animated user
interfaces.
This package provides upstream branding for SDDM.

%prep
%autosetup -p1

%build
%cmake \
      -DCMAKE_BUILD_TYPE=Release \
      -DMINIMUM_VT=7 \
      -DCMAKE_INSTALL_LIBEXECDIR="%{_libexecdir}/%{name}" \
      -DIMPORTS_INSTALL_DIR="%{_libdir}/qt5/qml" \
      -DSESSION_COMMAND="%{_sysconfdir}/X11/xdm/Xsession" \
      -DBUILD_MAN_PAGES=ON \
      -DSTATE_DIR="%{_localstatedir}/lib/sddm" \
      -DRUNTIME_DIR="/run/sddm" \
      -DPID_FILE="/run/sddm.pid"
  %make_jobs

%install
  %kf5_makeinstall -C build

  # We don't want the example config.
  # However, we need to package the file so it does not end up being removed.
  echo > %{buildroot}%{_sysconfdir}/sddm.conf

  pushd %{buildroot}%{_sysconfdir}/dbus-1/system.d
  mv org.freedesktop.DisplayManager.conf sddm_org.freedesktop.DisplayManager.conf
  popd

  install -Dm 0644 %{SOURCE1} %{buildroot}%{_libexecdir}/X11/displaymanagers/%{name}
  install -Dm 0644 %{SOURCE2} %{buildroot}%{_prefix}/lib/sddm/sddm.conf.d/00-general.conf
  install -Dm 0644 %{SOURCE3} %{buildroot}%{_prefix}/lib/sddm/sddm.conf.d/10-theme.conf
  install -Dm 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/sddm.conf
%if %{with sle_branding}
  install -Dm 0644 %{SOURCE5} %{buildroot}%{_prefix}/lib/sddm/sddm.conf.d/10-theme-SLE.conf
%endif

  mkdir -p %{buildroot}%{_sysconfdir}/alternatives
  touch %{buildroot}%{_sysconfdir}/alternatives/default-displaymanager
  ln -s %{_sysconfdir}/alternatives/default-displaymanager %{buildroot}%{_libexecdir}/X11/displaymanagers/default-displaymanager

  install -d %{buildroot}%{_rundir}/sddm
  install -d %{buildroot}%{_localstatedir}/lib/sddm
  install -d %{buildroot}%{_sysconfdir}/sddm.conf.d

  install -d %{buildroot}%{_sbindir}
  ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcsddm

  %fdupes %{buildroot}%{_datadir}/sddm

%pre
%service_add_pre sddm.service
getent group sddm >/dev/null || %{_sbindir}/groupadd -r sddm
getent passwd sddm >/dev/null || %{_sbindir}/useradd -r -g sddm -s /bin/false \
	-c "SDDM daemon" -d %{_localstatedir}/lib/sddm sddm

%post
%service_add_post sddm.service
%{_bindir}/systemd-tmpfiles --create %{_tmpfilesdir}/sddm.conf
if [ $1 -eq 2 -a -f %{_sysconfdir}/sddm.conf ]; then
    # Avoid changing sddm.conf's timestamp if no modifications done
    tempconf="$(mktemp)"

    # SDDM 0.14.0 moved maui into the built-in resources
    # SDDM <= 0.15.0 had no system config dir, so we need to remove the
    # moved configuration options from the old single config file
    sed -e 's/^Current=maui$/Current=/g' \
        -e '\#^DisplayCommand=%{_sysconfdir}/X11/xdm/Xsetup#d' \
        -e '\#^MinimumVT=7$#d' \
        -e '\#^ServerPath=%{_bindir}/X$#d' \
        -e '\#^SessionCommand=%{_sysconfdir}/X11/xdm/Xsession$#d' \
        %{_sysconfdir}/sddm.conf > "${tempconf}"

    cmp -s "${tempconf}" "%{_sysconfdir}/sddm.conf" || cp "${tempconf}" "%{_sysconfdir}/sddm.conf"
    rm "${tempconf}"
fi
%{_sbindir}/update-alternatives --install %{_libexecdir}/X11/displaymanagers/default-displaymanager \
  default-displaymanager %{_libexecdir}/X11/displaymanagers/sddm 25

%preun
%service_del_preun sddm.service

%postun
%service_del_postun sddm.service
[ -f %{_libexecdir}/X11/displaymanagers/sddm ] || %{_sbindir}/update-alternatives \
  --remove default-displaymanager %{_libexecdir}/X11/displaymanagers/sddm

%post branding-upstream
if [ $1 -eq 2 -a -f %{_sysconfdir}/sddm.conf ]; then
    # Avoid changing sddm.conf's timestamp if no modifications done
    tempconf="$(mktemp)"

    # SDDM <= 0.15.0 had no system config dir, so we need to remove the
    # theme configuration from the old single config file
    sed -e '/^Current=$/d' %{_sysconfdir}/sddm.conf > "${tempconf}"

    cmp -s "${tempconf}" "%{_sysconfdir}/sddm.conf" || cp "${tempconf}" "%{_sysconfdir}/sddm.conf"
    rm "${tempconf}"
fi
:

%post branding-openSUSE
if [ $1 -eq 2 -a -f %{_sysconfdir}/sddm.conf ]; then
    # Avoid changing sddm.conf's timestamp if no modifications done
    tempconf="$(mktemp)"

    # Upgrade from previous theme name
    # SDDM <= 0.15.0 had no system config dir, so we need to remove the
    # theme configuration from the old single config file
    sed -e 's/^Current=breeze$/Current=breeze-openSUSE/g' \
        -e 's/^Current=maui$/Current=breeze-openSUSE/g' \
        -e '/^Current=breeze-openSUSE$/d' \
        -e '/^CursorTheme=breeze_cursors$/d' %{_sysconfdir}/sddm.conf > "${tempconf}"

    cmp -s "${tempconf}" "%{_sysconfdir}/sddm.conf" || cp "${tempconf}" "%{_sysconfdir}/sddm.conf"
    rm "${tempconf}"
fi
:

%if %{with sle_branding}
%post branding-SLE
if [ $1 -eq 2 -a -f %{_sysconfdir}/sddm.conf ]; then
    # Avoid changing sddm.conf's timestamp if no modifications done
    tempconf="$(mktemp)"

    # Upgrade from previous theme name
    # SDDM <= 0.15.0 had no system config dir, so we need to remove the
    # theme configuration from the old single config file
    sed -e 's/^Current=breeze$/Current=breeze-SLE/g' \
        -e 's/^Current=maui$/Current=breeze-SLE/g' \
        -e '/^Current=breeze-SLE$/d' \
        -e '/^CursorTheme=breeze_cursors$/d' %{_sysconfdir}/sddm.conf > "${tempconf}"

    cmp -s "${tempconf}" "%{_sysconfdir}/sddm.conf" || cp "${tempconf}" "%{_sysconfdir}/sddm.conf"
    rm "${tempconf}"
fi
:
%endif

%files
%license LICENSE*
%doc README*
%config(noreplace) %{_sysconfdir}/sddm.conf
%dir %{_sysconfdir}/sddm.conf.d/
%config %{_sysconfdir}/pam.d/sddm
%config %{_sysconfdir}/pam.d/sddm-autologin
%config %{_sysconfdir}/pam.d/sddm-greeter
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/sddm_org.freedesktop.DisplayManager.conf
%dir %{_libexecdir}/X11/displaymanagers/
%{_libexecdir}/X11/displaymanagers/%{name}
%{_libexecdir}/X11/displaymanagers/default-displaymanager
%ghost %{_sysconfdir}/alternatives/default-displaymanager
%{_bindir}/sddm
%{_bindir}/sddm-greeter
%{_sbindir}/rcsddm
%{_libdir}/qt5/qml/
%dir %{_datadir}/sddm/
%dir %{_prefix}/lib/sddm/
%dir %{_prefix}/lib/sddm/sddm.conf.d/
%{_prefix}/lib/sddm/sddm.conf.d/00-general.conf
%{_libexecdir}/sddm/sddm-helper
%{_datadir}/sddm/faces/
%{_datadir}/sddm/flags/
%{_datadir}/sddm/scripts/
%{_datadir}/sddm/themes/
%{_datadir}/sddm/translations/
%ghost %attr(711,sddm,sddm) %dir %{_rundir}/sddm
%ghost %attr(750,sddm,sddm) %dir %{_localstatedir}/lib/sddm
%{_mandir}/man*/sddm*%{ext_man}
%{_unitdir}/sddm.service
%{_tmpfilesdir}/sddm.conf

%files branding-openSUSE
%license LICENSE*
%doc README*
%{_prefix}/lib/sddm/sddm.conf.d/10-theme.conf

%if %{with sle_branding}
%files branding-SLE
%license LICENSE*
%doc README*
%{_prefix}/lib/sddm/sddm.conf.d/10-theme-SLE.conf
%endif

%files branding-upstream
%license LICENSE*
%doc README*

%changelog
* Tue Nov  3 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix X not having access control on startup
  (boo#1177201, CVE-2020-28049):
  * 0001-Fix-X-not-having-access-control-on-startup.patch
  * 0002-Don-t-disable-authentication-in-test-mode.patch
* Wed Aug 21 2019 Antonio Larrosa <alarrosa@suse.com>
- Add SLE branding package for PackageHub (boo#1101297)
- Change the Supplements of branding packages, so they get installed
  when sddm and the respective branding package is installed. Also
  added a Supplements to sddm so it gets recommended when
  plasma5-workspace is installed.
* Mon Feb 18 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix reading garbage from getpwnam (boo#1125624):
  * 0001-Use-C-scoping-for-handling-buffer-deletion.patch
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Do not ignore errors from useradd.
* Sun Jan  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add the dirs created by systemd-tmpfiles as %%ghost as well
- Use service macros and create rcsddm link for sddm.service
* Fri Jan  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to delete socket on shutdown:
  * 0001-Destroy-the-QLocalServer-in-Auth-on-shutdown.patch
- Move creation of runtime directories and cleanup of files on boot
  into sddm-tmpfiles.conf (boo#1116431)
* Wed Oct  3 2018 fabian@ritter-vogt.de
- Remove 0001-Don-t-leak-VT-FDs-in-jumpToVt.patch as the FD leak
  worked around a race condition as a side effect
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Add patch to not leak tty FDs for wayland sessions:
  * 0001-Don-t-leak-VT-FDs-in-jumpToVt.patch
* Thu Sep 27 2018 fabian@ritter-vogt.de
- Fix wayland session start if fish is used as shell:
  * 0001-Revert-Adds-sourcing-of-etc-profile-to-fish.patch
* Sun Sep 23 2018 fabian@ritter-vogt.de
- Rewrite sddm-relaxed-auth.diff as sddm-relaxed-auth.patch:
  * Set XAUTHLOCALHOSTNAME only where necessary
  * Also set it for the Greeter session (boo#1091784)
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Add patch to not switch to "undead" sessions (boo#1102832):
  * 0001-Session-reuse-Only-consider-online-sessions.patch
- Reenable ReuseSession=true again
* Fri Jul 27 2018 fabian@ritter-vogt.de
- Disable ReuseSession=true for now (boo#1102832, kde#391253)
* Wed Jul 18 2018 fabian@ritter-vogt.de
- Update to 0.18.0:
  * Support theme supplied avatars
  * Compile against Qt 5.11
  * Fix platform detection for HighDPI
  * On close, switch VT to a running session if applicable
  * Better ConsoleKit support
  * Fix authentication when reusing existing sessions
  * Hide sessions with NoDisplay=true
  * Honor PAM's ambient supplemental groups
  * Cleanup socket destruction
  * Don't quit on SIGHUP
  * Updated translations
- Set EnableHiDPI=true by default (boo#1089932)
- Set ReuseSession=true by default (boo#979775)
- Drop patches, now upstream:
  * 0001-Don-t-add-session-files-with-NoDisplay-true-to-Sessi.patch
  * 0001-Don-t-quit-on-SIGHUP.patch
  * 0001-Fix-authentication-when-reusing-an-existing-session.patch
  * 0001-Fix-build-with-Qt-5.10-Use-QString-instead-of-QLatin.patch
  * 0001-Fix-build-with-Qt-5.11-1024.patch
  * 0001-Fix-platform-detection-for-EnableHiDPI.patch
  * 0001-Skip-theme-for-greeter-call-if-none-is-set.patch
  * 0001-Support-for-theme-supplied-default-avatars.patch
  * 0001-greeter-Use-Qt-command-line-parser.patch
  * 0002-Remove-trailing-spaces.patch
  * 0003-UserModel-optimize-filtering-out-duplicate-users-995.patch
  * 0004-UserModel-fix-filtering-out-duplicate-users-998.patch
  * 0005-UserModel-optimize-setting-of-default-user-icon-999.patch
  * 0007-Honor-PAMs-ambient-supplemental-groups.patch
- Refresh patches:
  * proper_pam.diff
  * 0001-Systemd-service-unit-Use-tty7-by-default.patch
* Mon Jul 16 2018 fabian@ritter-vogt.de
- Add patch to fix fallback to embedded theme:
  * 0001-Skip-theme-for-greeter-call-if-none-is-set.patch
- Use %%license
- Add patch to fix authentication when reusing an existing session
  (boo#1101450, CVE-2018-14345):
  * 0001-Fix-authentication-when-reusing-an-existing-session.patch
* Sat Jul  7 2018 w01dnick@gmail.com
- Fix 0001-Support-both-X11-XDisplay-Wayland-and-WaylandDisplay.patch
  * Corrected section name for Wayland
* Tue Jul  3 2018 fabian@ritter-vogt.de
- Remove patch as libxcb bug is fixed meanwhile (bsc#1099908):
  * 0001-Move-Xauthority-to-a-different-location-and-truncate.patch
* Mon Jul  2 2018 luizluca@gmail.com
- Backport fix for pam_group from develop branch (boo#1105342):
  * 0007-Honor-PAMs-ambient-supplemental-groups.patch
* Mon May 14 2018 fabian@ritter-vogt.de
- Add patch to not include sessions with NoDisplay=true in the list (boo#1086614):
  * 0001-Don-t-add-session-files-with-NoDisplay-true-to-Sessi.patch
* Wed May  9 2018 fabian@ritter-vogt.de
- Amend patch to also canonicalize desktop session paths (boo#1092251):
  * 0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
- Add patch to fix build with Qt 5.11:
  * 0001-Fix-build-with-Qt-5.11-1024.patch
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Add patch to show a username input field with too many users:
  * 0006-Don-t-fill-UserModel-if-theme-does-not-require-it.patch
- Backport related changes from develop branch:
  * 0001-Support-for-theme-supplied-default-avatars.patch
  * 0002-Remove-trailing-spaces.patch
  * 0003-UserModel-optimize-filtering-out-duplicate-users-995.patch
  * 0004-UserModel-fix-filtering-out-duplicate-users-998.patch
  * 0005-UserModel-optimize-setting-of-default-user-icon-999.patch
* Mon Apr 16 2018 fabian@ritter-vogt.de
- Revert previous change, had the opposite effect for some reason
* Thu Apr 12 2018 fabian@ritter-vogt.de
- Start the X server with -keeptty (boo#1089287)
* Sat Mar 24 2018 fabian@ritter-vogt.de
- Don't add a suffix for wayland sessions anymore, for symmetry with
  gdm and lightdm:
  * 0001-Remove-suffix-for-Wayland-session.patch
* Thu Mar 22 2018 fabian@ritter-vogt.de
- Add patch to fix build with Qt < 5.10:
  * 0001-Fix-build-with-Qt-5.10-Use-QString-instead-of-QLatin.patch
* Fri Mar  9 2018 fabian@ritter-vogt.de
- Reorder patches for easier maintainability, needs refresh of:
  * 0001-Move-Xauthority-to-a-different-location-and-truncate.patch
  * 0001-Read-the-DISPLAYMANAGER_AUTOLOGIN-value-from-sysconf.patch
  * sddm-relaxed-auth.diff
- Replace 0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch
  with 0001-Support-both-X11-XDisplay-Wayland-and-WaylandDisplay.patch
- Add patches to fix setting EnableHiDPI in the configuration:
  * 0001-greeter-Use-Qt-command-line-parser.patch
  * 0001-Fix-platform-detection-for-EnableHiDPI.patch
* Sat Mar  3 2018 fabian@ritter-vogt.de
- Add patch to not quit on SIGHUP (boo#1080305):
  * 0001-Don-t-quit-on-SIGHUP.patch
* Fri Feb 23 2018 alarrosa@suse.com
- Only use python-doctools when building for SLE12 since SLE15 has
  rst2man in python3-doctools.
* Thu Dec 14 2017 fabian@ritter-vogt.de
- Update to 0.17.0:
  + Added possibility to change border width of ComboBox widget.
  + Added missing utmp/wtmp/btmp handling.
  + Make greeter see icons set by AccountsServices.
  - Fix sddm.conf man page syntax error and update.
  - Fix ComboBox widget.
  - Fix connection of PropertiesChanged event for LogindSeat.
  - Avoid race conditions with Xsetup.
  * Update de translation.
  * Update lt translation.
  * Update zh_TW translation.
  * Adjust order of components in the default PATH.
  * Set default input method to qtvirtualkeyboard.
- Update to 0.16.0:
  + Support non-latin characters in theme settings.
  + Support fish shell in Xsession and wayland-session.
  + Unlock GNOME keyring at login.
  + Configuration directory.
  - Make the default cursor themed.
  - Update date and time in elarun theme.
  - Fix theme metadata default values.
  - Fix session selection in elarun.
  - Do not truncate XAUTHORITY on login.
  - Make enabled property of Button functional.
  - Fix typos in documentation.
  * Re-use existing sessions.
  * Add ConsoleKit 2 support.
  * Stop assuming shadow(5) is always available.
  * Explicitely set XDG_SEAT when starting a user session.
  * Suppress errors when pam_elogind is not available.
  * Suppress errors when pam_systemd is not available.
  * Added possibility to change color of dropdown menu.
  * Add Hindi translation.
  * Completed Swedish translation.
  * Update French translation.
- Move to system configuration dirs, replace sddm.conf with
  00-general.conf and 10-theme.conf
- Refresh patches:
  * 0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch
  * proper_pam.diff
- Rename patches:
  * sysconfig-support.patch:
    0001-Read-the-DISPLAYMANAGER_AUTOLOGIN-value-from-sysconf.patch
  * create_pid_file.patch:
    0001-Write-the-daemon-s-PID-to-a-file-on-startup.patch
- Remove patches, now upstream:
  * 0001-Do-not-truncate-XAUTHORITY-file-on-login.patch
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Add patch to add back Xauthority truncation in a way that does
  not break ssh -X (boo#1043221, boo#1069498):
  * 0001-Move-Xauthority-to-a-different-location-and-truncate.patch
* Tue Nov 28 2017 fabian@ritter-vogt.de
- Amend patch toremove elogind from sddm-greeter.pam:
  * proper_pam.diff
* Sat Oct 28 2017 tschmidt@suse.com
- Add "Requires: xdm" because sddm.conf references the files
  '/etc/X11/xdm/Xsession' and '/etc/X11/xdm/Xsetup'
* Thu Oct 12 2017 dimstar@opensuse.org
- Have update-alternatives handle Xinit's integration of the
  displaymanager, replacing /etc/sysconfig/displaymanager
  (boo#1053863).
* Fri Sep  1 2017 fabian@ritter-vogt.de
- Update to 0.15.0:
  * Fix loading of some avatars
  * CONFIG: add option EnableHiDPI to allow opt out of auto scaling
  * Theme cursor
  * Support optional kwallet PAM opening
  * Autologin, used last used session if not explicitly set in config
  * Ignore session desktop files with hidden=true
  * Support elogind
  * Many new and improved translations
- Remove patches, now upstream:
  * 0001-Also-set-QT_IM_MODULE-in-non-testing-mode.patch
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
  * 0001-Fix-display-of-user-avatars.-684.patch
  * 0001-Make-the-default-cursor-themed.patch
  * 0001-Parse-desktop-file-sections.patch
  * 0002-Add-a-config-option-to-enable-high-DPI-scaling-701.patch
  * 0002-Ignore-session-desktop-files-with-the-Hidden-propert.patch
  * 0003-elarun-Update-date-and-time.patch
  * 0004-Support-Non-Latin-characters-in-theme-settings-708.patch
  * 0005-Cleanup-dangling-pointer-in-SocketServer-725.patch
- Refresh patches:
  * 0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch
  * proper_pam.diff
* Mon Jul 10 2017 fabian@ritter-vogt.de
- Replace patch with version merged upstream, to avoid potentially
  killing the X server:
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
* Fri Jul  7 2017 fabian@ritter-vogt.de
- Add patch to keep old entries in XAUTHORITY file (boo#1043221):
  * 0001-Do-not-truncate-XAUTHORITY-file-on-login.patch
* Fri May 19 2017 fabian@ritter-vogt.de
- Also set the default last session in sysconfig-support.patch
  (replaces boo949903.patch)
- Adjust 0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
  to also handle symlinks for the last session
* Thu May 18 2017 fabian@ritter-vogt.de
- Replace patch with newer version:
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
* Mon May 15 2017 fvogt@suse.com
- Add upstream patches:
  * 0001-Parse-desktop-file-sections.patch
  * 0002-Ignore-session-desktop-files-with-the-Hidden-propert.patch
- Add downstream patch:
  * 0003-Leave-duplicate-symlinks-out-of-the-SessionModel.patch
- Fix typo in sysconfig-support.patch (DYSPLAY -> DISPLAY)
- Use default.desktop as default autologin session file
* Mon May  8 2017 fabian@ritter-vogt.de
- BuildRequire python-docutils instead of python3-docutils on SLE
* Fri May  5 2017 fabian@ritter-vogt.de
- Add patch to fix the default X cursor appearing sometimes:
  * 0001-Also-theme-the-default-cursor-for-the-root-window.patch
* Tue Apr 25 2017 fabian@ritter-vogt.de
- BuildRequire python3-docutils directly
* Sat Apr  1 2017 fabian@ritter-vogt.de
- Use default tty (tty7) in systemd unit as specified in sddm.conf:
  * 0001-Systemd-service-unit-Use-tty7-by-default.patch
- Add patch from upstream to allow setting QT_IM_MODULE in sddm.conf:
  * 0001-Also-set-QT_IM_MODULE-in-non-testing-mode.patch
* Fri Mar 31 2017 fabian@ritter-vogt.de
- Revert calling plymouth quit with --retain-splash. It is possible
  that this prevents logging in on tty1.
* Fri Mar 17 2017 jengelh@inai.de
- Ensure neutrality of descriptions.
* Wed Mar  8 2017 wbauer@tmo.at
- Call "plymouth quit --retain-splash" instead of "plymouth_quit"
  in the displaymanager script to hide the text mode login prompt
  during boot (the dedicated sddm.service does the same).
- Also, don't call xdm_reload_files, that just re-generates the xdm
  config files according to the sysconfig values and only makes
  sense for xdm.
* Sat Dec 17 2016 fabian@ritter-vogt.de
- Fix typos in description
* Fri Nov 25 2016 fabian@ritter-vogt.de
- Fix %%post and %%postun of branding subpackages
* Mon Nov 21 2016 fabian@ritter-vogt.de
- Add various bugfixes from develop branch:
  * 0001-Fix-display-of-user-avatars.-684.patch
  * 0002-Add-a-config-option-to-enable-high-DPI-scaling-701.patch
  * 0003-elarun-Update-date-and-time.patch
  * 0004-Support-Non-Latin-characters-in-theme-settings-708.patch
  * 0005-Cleanup-dangling-pointer-in-SocketServer-725.patch
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Sync with KDE:Frameworks5:LTS, sort sddm.changes
- Remove 0001-Fall-back-to-regular-login-when-autologin-fails.patch
* Sat Sep 24 2016 fabian@ritter-vogt.de
- Add 0001-Fall-back-to-regular-login-when-autologin-fails.patch
  to fix crash when autologin session not found (boo#1000917)
* Thu Sep 22 2016 fabian@ritter-vogt.de
- Add 0001-Make-the-default-cursor-themed.patch to fix the default
  cursor appearance
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Provide sddm-lang
* Thu Sep 15 2016 alarrosa@suse.com
- Use the new theme name, breeze-openSUSE, in sddm-branding-openSUSE
- Require the new sddm-theme-openSUSE package
* Mon Aug 29 2016 fabian@ritter-vogt.de
- Update to 0.14.0:
  - http://hawaiios.org/news/2016/08/28/sddm-0.14.0
    + New sddm.conf option EnableAvatars (useful for slow filesystems)
    + New sddm.conf option UserAuthFile on the XDisplay section
    to change the default Xauthority file name and path.
    + New sddm.conf option SessionLogFile on XDisplay and WaylandDisplay
    sections to change the default user session log location.
    + ComboBox now exposes the arrow background color as
    "arrowColor" property.
    + New "style" theme configuration for QtQuick Controls 2.0.
    + Require Qt 5.6 or better.
    + Enable HiDPI support.
    + Refresh sessions list.
    + Always fallback to an embedded theme if no suitable theme is found.
  - Actually change Qt platform theme.
  - Switch to Wayland session vt only when authentication
    succeeds.
  - Close PAM session.
  - Delete PAM credentials after closing the session.
  * More theme-neutral default user and root avatars
  * REMOVED the "circles" theme. Remember to change it if you had it set!
  * REMOVED the "maui" theme as a standalone theme as it is now
    embedded in the greeter. Remember to change the theme to empty
    if you had it set to "maui".
  * Update Estonian translation.
  * Add Catalan translation from Robert Antoni Buj Gelonch.
  * Add Dutch translation from Eric Hameleers.
  * Add Slovak translation from Martin Minka.
  * Add Swedish translation from Kristoffer Grundström.
  * Add Ukrainian translation from Cherevan Andriy.
  * Add Indian flag from Sanjeev Premi.
- Refresh patches:
  - sddm-relaxed-auth.diff
  - sddm-service-handle-plymouth.patch
  - sysconfig-support.patch
- Remove upstream patches:
  - 0001-Add-a-config-option-to-enable-avatars.patch
  - 0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch
  - root.face.icon.png
  - default.face.icon.png
- Remove upstreamed patches:
  - add-count-property-to-UserModel.patch
  - add-threshold-to-disable-avatars.patch
  - specify-default-config-entries.patch
- Revert upstream config section name change (gh#sddm/sddm#680):
  - 0001-Revert-Rename-XDisplay-and-WaylandDisplay-config-sec.patch
- Use "Current=" instead of "Current=maui"
* Wed Jun  8 2016 fbui@suse.com
- Fix build requirements on systemd (bsc#983167)
  Use pkgconfig() so we don't need to rely on package names. For the
  record, systemd.pc is now part of systemd main package.
* Fri Nov 20 2015 alarrosa@suse.com
- Renamed config option and property from UsersThresholdToDisableAvatars
  to DisableAvatarsThreshold as proposed by upstream before accepting
  the patches.
* Wed Nov 11 2015 alarrosa@suse.com
- Add patch add-count-property-to-UserModel.patch: Adds a property so
  sddm themes can access the number of users in the system
- Add patch specify-default-config-entries.patch: Stores which config
  values have been read from the config file or are just default values.
- Add patch add-threshold-to-disable-avatars.patch: Adds a config option
  and property named UsersThresholdToDisableAvatars, if the number of
  users in the system is greater than the threshold, use a default avatar
  for all users and disable avatar loading.
- These patches together with patches in plasma5-workspace fix bnc#953778
* Fri Nov  6 2015 alarrosa@suse.com
- Update to 0.13.0:
  * Greeter inherits path environment variables from parent so that
    themes installed in non-standard paths will work.
  * Add ENABLE_PAM option to toggle PAM support at build time.
  * Allow overriding textColor in ComboBox.
  * Don't cast QByteArray to (char *).
  * Disable greeters from loading KDE's debug hander
    (fix CVE-2015-0856).
  * Fix multi-screen support for some setups.
  * Added Serbian translation.
  * Added Traditional Chinese translation.
  * Improved German translation.
  * Remove failsafe session entry.
  * Close the pipe fd passed to X server.
  * A few micro-optimizations.
- Removed patches already in this version:
    0001-always-create-window-for-each-screen.patch
    0002-screen-model-for-each-window.patch
    0001-Don-t-cast-QByteArray-to-char.patch
    0002-Disable-greeters-from-loading-KDE-s-debug-hander.patch
- Updated patches to apply cleanly:
    boo949903.patch
    sddm-relaxed-auth.diff
    sysconfig-support.patch
- Added patches from upstream to add a config option that can be
  used to disable the loading of user avatars (EnableAvatars):
    0001-Add-a-config-option-to-enable-avatars.patch
    0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch
* Sat Oct 24 2015 tchvatal@suse.com
- Add upstream patches to fix multihead in some cases
  (also fixes boo#950293):
  * 0001-always-create-window-for-each-screen.patch
  * 0002-screen-model-for-each-window.patch
* Sun Oct 18 2015 hrvoje.senjan@gmail.com
- openSUSE branding now needs to require plasma5-workspace-branding
* Thu Oct 15 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Don-t-cast-QByteArray-to-char.patch
  (https://github.com/sddm/sddm/issues/489)
  and 0002-Disable-greeters-from-loading-KDE-s-debug-hander.patch
  (boo#950491, CVE-2015-0856)
* Sun Oct 11 2015 hrvoje.senjan@gmail.com
- Added boo949903.patch: Let sddm also default to plasma5 for last
  used session (boo#949903)
* Thu Sep 24 2015 hrvoje.senjan@gmail.com
- Added shadow BuildRequires, it's needed to check UID_MIN & UID_MAX
  from /etc/login.defs
* Sat Sep 12 2015 wbauer@tmo.at
- Change the theme to "maui" in the shipped sddm.conf,
  sddm-branding-openSUSE sets it to "breeze" on installation.
- Remove the superfluous requirement for "breeze". This is not
  needed even with the "breeze" theme, as it is actually part of
  plasma5-workspace which is required by sddm-branding-openSUSE
  anyway.
- sddm-branding-openSUSE should PreReq sddm, otherwise the config
  might not exist.
- Make the regexps for sed stricter to really only modify the theme
  setting when installing/uninstalling sddm-branding-openSUSE.
  Otherwise it would e.g. also replace CursorTheme=breeze_cursors
  with CursorTheme=maui_cursors...
  Also only modify the config on new installation, not during
  updates.
* Sun Sep  6 2015 hrvoje.senjan@gmail.com
- Update to 0.12.0:
  * SDDM now depends on Qt >= 5.3
  * Display setup script is now killed if it hasn't finished
    within 30 seconds.
  * The Maldives non-free background has been replaced by a
    CC-BY-SA alternative
  * Wayland sessions support
  * New sddm.conf option XephyrPath
    (defaults to /usr/bin/Xephyr)
  * new sddm.conf option ServerArguments
    (defaults to -nolisten tcp)
  * new sddm.config option DisplayStopCommand (executes Xstop)
  * Assorted improvements to the default theme
  * Honor TryExec in Xsession desktop files
  * Fix session startup on zsh
  * Allow setting a custom DBUS_CONFIG_FILENAME at compile time
  * Allow SYSTEMD_SYSTEM_UNIT_DIR to be overridden at compile time
  * Allow QT_IMPORTS_DIR to be overridden at compile time
  * No longer hardcode min/max UIDs, allow setting
    UID_MIN and UID_MAX at compile time
  * Assorted FreeBSD fixes
  * Fix build warnings with Qt 5.5.
  * Enable QT_NO_CAST_FROM_ASCII
  * Added Arabic
  * Added Hungarian
  * Various i18n updates and improvements
  * Full right-to-left languages support.
- Drop sddm-wait-for-display-script.patch, merged upstream
* Wed Aug 26 2015 herbert@graeber-clan.de
- Added patch from upstream sddm-wait-for-display-script.patch:
  avoid a black screen (boo#942815)
* Mon Jun  1 2015 dimstar@opensuse.org
- Do not split out a -lang package: the translations are not in
  standard locations and having the -lang package confuses
  bundle-lang-kde, which can't move the files to the bundle, thus
  resulting in conflicting packages.
* Mon May 25 2015 hrvoje.senjan@gmail.com
- Add sddm-service-handle-plymouth.patch -- sddm has some rudimentary
  support for plymouth handling, which only works with
  plymouth-quit.service (the servce is not enabled on openSUSE).
  For users of sddm.service, we need to issue plymouth quit command
  by hand in this case
* Mon May  4 2015 hrvoje.senjan@gmail.com
- Add sysconfig-support.patch: Support DISPLAYMANAGER_AUTOLOGIN
  entry from /etc/sysconfig/displaymanager, the value overwrites
  any entry in sddm.conf/[Autologin]/User. Patch also defaults
  to plasma5.desktop as default autologin and last selected
  sessions. This is controlled only by sddm.conf file.
- Mark sddm.conf as %%config(noreplace)
* Wed Apr 29 2015 hrvoje.senjan@gmail.com
- Added sddm-relaxed-auth.diff: Insert XAUTHLOCALHOSTNAME into
  users enviroment, so the session handles hostname changes with
  a single X instance/run
- Use breeze_cursors in openSUSE branding
* Mon Mar 16 2015 hrvoje.senjan@gmail.com
- Drop conflict with lightdm, and move DBus configuration file,
  now that sddm is whitelisted
- Drop xdm (Build)Requires
- Install sddm-pam* directly, instead of messing with symlinking
- Add create_pid_file.patch: openSUSE's generic display-manager
  service doesn't know what to do without a pid file. drop the patch
  as soon as that sick dinosaur is killed
- Drop ommit_systemd_service.patch
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Add conflict with lightdm due to same DBus configuration file
* Mon Dec  8 2014 hrvoje.senjan@gmail.com
- Update to 0.11.0
  * Reload the configuration every time we start a new session
  * Fix stderr redirection in the helper. Solving a memory leak
  * Set system locale in the greeter
  * Bail on chdir failure
  * Use QUuid for unique ID generation
  * Update lithuanian translations
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Create openSUSE and upstream branding packages, now only openSUSE
  branding depends on plasma5-workspace
* Fri Oct 17 2014 hrvoje.senjan@gmail.com
- Update to 0.10.0:
  * BACKWARDS INCOMPATIBLE: Drop support for Qt 4.
  * BACKWARDS INCOMPATIBLE: SDDM now prioritizes loading sessions
    with a .desktop prefix
  * SECURITY: Never try to login as the sddm user (CVE-2014-7271)
  * SECURITY: Fix race condition in XAUTHORITY file generation
    (CVE-2014-7272)
  * SECURITY: XAUTHORITY file is no longer owned by root
  * New translation: Kazakh
  * Fixed password field initial focus state
  * When the default theme is not available, sddm now loads the
    first theme in alphabetical order
  * Fixed PAM environment variables being overridden
  * Fixed autologin with the passwd backend
  * Greeter themes can now specify their own icon and
    cursor themes.
  * Various bugfixes with SessionCommand/XSession support
  * Various bugfixes with test mode.
  * Various cleanups
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 0.9.9~git20141009:
  * resolved CVE-2014-7272 and bnc#897788
  * Dropped support for Qt4
  * Flush any buffered data to the log file, this writes
    immediately all the log messages.
  * Don't override pam environment variables.
  * Set default icon theme from greeter theme configuration.
  * Set cursor theme according to greeter theme configuration.
- Drop 0001-Never-try-to-login-as-the-user-SDDM.patch,
  0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch
  and 0001-Don-t-override-pam-environment-variables.patch: merged
  upstream
* Mon Oct  6 2014 hrvoje.senjan@gmail.com
- Added 0001-Never-try-to-login-as-the-user-SDDM.patch and
  0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch to
  resolve bnc#897788 and CVE-2014-7272
- Leave 0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch
  disabled for the moment, as it completely breaks users login
* Sun Sep 21 2014 hrvoje.senjan@gmail.com
- Make it build for 13.1: define /rundir if undefined
- 0001-Don-t-override-pam-environment-variables.patch: fixes
  https://github.com/sddm/sddm/issues/256
* Thu Aug 21 2014 hrvoje.senjan@gmail.com
- Update to 0.9.0
  * Several systemd, logind and journald improvements. Note that
    systemd is not required to run SDDM.
  * The SDDM greeter now runs as its own user and group, instead
    of root.
  * Support for setting the keyboard layout from the greeter.
  * An "AutoUser" config key to configure automatic login.
  * A "NumLock" config key to configure NumLock state at boot.
  * Overhauled configuration file handling.
  * SDDM runs with the default configuration without /etc/sddm.conf
  * Initial (albeit not fully functional) Plymouth support.
  * Translations in 11 languages.
  * Several licensing and packaging improvements.
  * Better documentation, including man pages for sddm(1),
    sddm-greeter(1), sddm.conf(5) and sddm-state.conf(5).
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Update to latest snapshot
- Added pkgconfig(xcb-xkb) BuildRequires
- Dropped libupower-glib-devel BuildRequire
- Utilize systemd macros for sddm service
- Small spec cleanup
- Use sed instead of two patches
* Sun Mar 17 2013 hrvoje.senjan@gmail.com
- Initial packaging of sddm, Lightweight QML-based display manager
